# -*- coding: utf-8 -*-
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from django.contrib.auth.decorators import login_required

from taobaoapi import *
from social.apps.django_app.default.models import UserSocialAuth

@login_required
def user_info(request):
    print request.user.id
    user = get_object_or_404(UserSocialAuth.objects.filter(provider='taobao'),user=request.user)
    token = user.extra_data['access_token']
    t = TaoBao()
    t.setParams(access_token=token, method='taobao.user.seller.get')
    t.setFields('nick,sex')
    return render_to_response("taobao/index.html", RequestContext(request, {'seller':t.fetch()}))



#coding=utf8
import urllib,urllib2,time,md5,json
from django.conf import settings

TAOBAO_API_URL = settings.TAOBAO_API_URL

class TaoBao(object):
    def __init__(self):
        self.datas = ''
        self.p = dict(
            method = '',
            v = '2.0',
            format = 'json',
            fields = 'is_success',
        )
    def setParams(self,**kwargs):
        self.p.update(kwargs)
    def setFields(self,fields):
        self.p['fields'] = fields
    def setFormat(self,format):
        if format in ('json','xml'):self.p['format'] = format
    def fetch(self):
        form_data = urllib.urlencode(self.p)
        urlopen = urllib2.urlopen(TAOBAO_API_URL,form_data)
        print TAOBAO_API_URL+'?'+form_data
        rsp = urlopen.read()
        rsp = json.loads(rsp.decode('UTF-8'))
        if rsp.has_key('error_response'):
            return rsp['error_response']
        else:
            rsp = rsp[self.p['method'].replace('.','_').replace('taobao_','') + '_response']
            return rsp



from distutils.core import setup

setup(
    name='django-taobao',
    version='0.1.0',
    author='Jichao Ouyang',
    author_email='oyanglulu@gmail.com',
    packages=['taobao','taobao.templates','taobao.taobaoapi2'],
    url='https://github.com/geogeo/django-taobao',
    license='LICENSE.txt',
    description='Taobao saler tools for django.',
    long_description=open('README.txt').read(),
    install_requires=[
        "Django >= 1.3.1",
        "django-social-auth",
    ],
)




from setuptools import setup, find_packages
import os

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as f:
    long_description = f.read()
    
setup(
    name='django-taobao',
    version='0.2.5',
    author='Jichao Ouyang',
    author_email='oyanglulu@gmail.com',
    packages=find_packages(),
    url='https://github.com/jcouyang/django-taobao',
    license='MIT',
    keywords='django, taobao, oauth, api',
    description='Taobao SDK for django.',
    long_description=long_description
)

